from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class ace(_message.Message):
    __slots__ = ["_id", "deny", "rights"]
    DENY_FIELD_NUMBER: _ClassVar[int]
    RIGHTS_FIELD_NUMBER: _ClassVar[int]
    _ID_FIELD_NUMBER: _ClassVar[int]
    _id: str
    deny: bool
    rights: int
    def __init__(self, _id: _Optional[str] = ..., deny: bool = ..., rights: _Optional[int] = ...) -> None: ...



from google.protobuf import timestamp_pb2 as _timestamp_pb2
from google.protobuf import any_pb2 as _any_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class beginstream(_message.Message):
    __slots__ = ["checksum", "stat"]
    CHECKSUM_FIELD_NUMBER: _ClassVar[int]
    STAT_FIELD_NUMBER: _ClassVar[int]
    checksum: str
    stat: stat
    def __init__(self, checksum: _Optional[str] = ..., stat: _Optional[_Union[stat, _Mapping]] = ...) -> None: ...

class clientconsole(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class console(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class customcommand(_message.Message):
    __slots__ = ["command", "data", "id", "name"]
    COMMAND_FIELD_NUMBER: _ClassVar[int]
    DATA_FIELD_NUMBER: _ClassVar[int]
    ID_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    command: str
    data: str
    id: str
    name: str
    def __init__(self, command: _Optional[str] = ..., id: _Optional[str] = ..., name: _Optional[str] = ..., data: _Optional[str] = ...) -> None: ...

class customcommandreply(_message.Message):
    __slots__ = ["result"]
    RESULT_FIELD_NUMBER: _ClassVar[int]
    result: str
    def __init__(self, result: _Optional[str] = ...) -> None: ...

class download(_message.Message):
    __slots__ = ["filename", "id"]
    FILENAME_FIELD_NUMBER: _ClassVar[int]
    ID_FIELD_NUMBER: _ClassVar[int]
    filename: str
    id: str
    def __init__(self, id: _Optional[str] = ..., filename: _Optional[str] = ...) -> None: ...

class downloadreply(_message.Message):
    __slots__ = ["filename", "id", "mimetype"]
    FILENAME_FIELD_NUMBER: _ClassVar[int]
    ID_FIELD_NUMBER: _ClassVar[int]
    MIMETYPE_FIELD_NUMBER: _ClassVar[int]
    filename: str
    id: str
    mimetype: str
    def __init__(self, id: _Optional[str] = ..., filename: _Optional[str] = ..., mimetype: _Optional[str] = ...) -> None: ...

class endstream(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class envelope(_message.Message):
    __slots__ = ["command", "data", "hash", "id", "priority", "rid", "seq", "spanid", "traceid"]
    COMMAND_FIELD_NUMBER: _ClassVar[int]
    DATA_FIELD_NUMBER: _ClassVar[int]
    HASH_FIELD_NUMBER: _ClassVar[int]
    ID_FIELD_NUMBER: _ClassVar[int]
    PRIORITY_FIELD_NUMBER: _ClassVar[int]
    RID_FIELD_NUMBER: _ClassVar[int]
    SEQ_FIELD_NUMBER: _ClassVar[int]
    SPANID_FIELD_NUMBER: _ClassVar[int]
    TRACEID_FIELD_NUMBER: _ClassVar[int]
    command: str
    data: _any_pb2.Any
    hash: str
    id: str
    priority: int
    rid: str
    seq: int
    spanid: str
    traceid: str
    def __init__(self, command: _Optional[str] = ..., priority: _Optional[int] = ..., seq: _Optional[int] = ..., hash: _Optional[str] = ..., id: _Optional[str] = ..., rid: _Optional[str] = ..., traceid: _Optional[str] = ..., spanid: _Optional[str] = ..., data: _Optional[_Union[_any_pb2.Any, _Mapping]] = ...) -> None: ...

class error(_message.Message):
    __slots__ = ["code", "message", "stack"]
    CODE_FIELD_NUMBER: _ClassVar[int]
    MESSAGE_FIELD_NUMBER: _ClassVar[int]
    STACK_FIELD_NUMBER: _ClassVar[int]
    code: int
    message: str
    stack: str
    def __init__(self, message: _Optional[str] = ..., code: _Optional[int] = ..., stack: _Optional[str] = ...) -> None: ...

class getelement(_message.Message):
    __slots__ = ["xpath"]
    XPATH_FIELD_NUMBER: _ClassVar[int]
    xpath: str
    def __init__(self, xpath: _Optional[str] = ...) -> None: ...

class noop(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class ping(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class pong(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class refreshtoken(_message.Message):
    __slots__ = ["jwt", "user", "username"]
    JWT_FIELD_NUMBER: _ClassVar[int]
    USERNAME_FIELD_NUMBER: _ClassVar[int]
    USER_FIELD_NUMBER: _ClassVar[int]
    jwt: str
    user: user
    username: str
    def __init__(self, username: _Optional[str] = ..., jwt: _Optional[str] = ..., user: _Optional[_Union[user, _Mapping]] = ...) -> None: ...

class role(_message.Message):
    __slots__ = ["_id", "name"]
    NAME_FIELD_NUMBER: _ClassVar[int]
    _ID_FIELD_NUMBER: _ClassVar[int]
    _id: str
    name: str
    def __init__(self, _id: _Optional[str] = ..., name: _Optional[str] = ...) -> None: ...

class send(_message.Message):
    __slots__ = ["count"]
    COUNT_FIELD_NUMBER: _ClassVar[int]
    count: int
    def __init__(self, count: _Optional[int] = ...) -> None: ...

class signin(_message.Message):
    __slots__ = ["jwt", "password", "ping", "username"]
    JWT_FIELD_NUMBER: _ClassVar[int]
    PASSWORD_FIELD_NUMBER: _ClassVar[int]
    PING_FIELD_NUMBER: _ClassVar[int]
    USERNAME_FIELD_NUMBER: _ClassVar[int]
    jwt: str
    password: str
    ping: bool
    username: str
    def __init__(self, username: _Optional[str] = ..., password: _Optional[str] = ..., jwt: _Optional[str] = ..., ping: bool = ...) -> None: ...

class signinreply(_message.Message):
    __slots__ = ["jwt", "user"]
    JWT_FIELD_NUMBER: _ClassVar[int]
    USER_FIELD_NUMBER: _ClassVar[int]
    jwt: str
    user: user
    def __init__(self, jwt: _Optional[str] = ..., user: _Optional[_Union[user, _Mapping]] = ...) -> None: ...

class stat(_message.Message):
    __slots__ = ["birthtimeMs", "blksize", "blocks", "ctime", "ctimeMs", "dev", "gid", "ino", "mode", "mtime", "mtimeMs", "nlink", "rdev", "size", "uid"]
    BIRTHTIMEMS_FIELD_NUMBER: _ClassVar[int]
    BLKSIZE_FIELD_NUMBER: _ClassVar[int]
    BLOCKS_FIELD_NUMBER: _ClassVar[int]
    CTIMEMS_FIELD_NUMBER: _ClassVar[int]
    CTIME_FIELD_NUMBER: _ClassVar[int]
    DEV_FIELD_NUMBER: _ClassVar[int]
    GID_FIELD_NUMBER: _ClassVar[int]
    INO_FIELD_NUMBER: _ClassVar[int]
    MODE_FIELD_NUMBER: _ClassVar[int]
    MTIMEMS_FIELD_NUMBER: _ClassVar[int]
    MTIME_FIELD_NUMBER: _ClassVar[int]
    NLINK_FIELD_NUMBER: _ClassVar[int]
    RDEV_FIELD_NUMBER: _ClassVar[int]
    SIZE_FIELD_NUMBER: _ClassVar[int]
    UID_FIELD_NUMBER: _ClassVar[int]
    birthtimeMs: float
    blksize: int
    blocks: int
    ctime: _timestamp_pb2.Timestamp
    ctimeMs: float
    dev: int
    gid: int
    ino: int
    mode: int
    mtime: _timestamp_pb2.Timestamp
    mtimeMs: float
    nlink: int
    rdev: int
    size: int
    uid: int
    def __init__(self, birthtimeMs: _Optional[float] = ..., blksize: _Optional[int] = ..., blocks: _Optional[int] = ..., ctime: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., ctimeMs: _Optional[float] = ..., dev: _Optional[int] = ..., gid: _Optional[int] = ..., ino: _Optional[int] = ..., mode: _Optional[int] = ..., mtime: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., mtimeMs: _Optional[float] = ..., nlink: _Optional[int] = ..., rdev: _Optional[int] = ..., size: _Optional[int] = ..., uid: _Optional[int] = ...) -> None: ...

class stream(_message.Message):
    __slots__ = ["data"]
    DATA_FIELD_NUMBER: _ClassVar[int]
    data: bytes
    def __init__(self, data: _Optional[bytes] = ...) -> None: ...

class upload(_message.Message):
    __slots__ = ["filename", "mimetype"]
    FILENAME_FIELD_NUMBER: _ClassVar[int]
    MIMETYPE_FIELD_NUMBER: _ClassVar[int]
    filename: str
    mimetype: str
    def __init__(self, filename: _Optional[str] = ..., mimetype: _Optional[str] = ...) -> None: ...

class uploadreply(_message.Message):
    __slots__ = ["bytes", "chunks", "elapsedTime", "filename", "id", "mb", "mbps"]
    BYTES_FIELD_NUMBER: _ClassVar[int]
    CHUNKS_FIELD_NUMBER: _ClassVar[int]
    ELAPSEDTIME_FIELD_NUMBER: _ClassVar[int]
    FILENAME_FIELD_NUMBER: _ClassVar[int]
    ID_FIELD_NUMBER: _ClassVar[int]
    MBPS_FIELD_NUMBER: _ClassVar[int]
    MB_FIELD_NUMBER: _ClassVar[int]
    bytes: int
    chunks: int
    elapsedTime: int
    filename: str
    id: str
    mb: float
    mbps: float
    def __init__(self, id: _Optional[str] = ..., filename: _Optional[str] = ..., bytes: _Optional[int] = ..., chunks: _Optional[int] = ..., mb: _Optional[float] = ..., elapsedTime: _Optional[int] = ..., mbps: _Optional[float] = ...) -> None: ...

class user(_message.Message):
    __slots__ = ["_id", "email", "name", "roles", "username"]
    EMAIL_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    ROLES_FIELD_NUMBER: _ClassVar[int]
    USERNAME_FIELD_NUMBER: _ClassVar[int]
    _ID_FIELD_NUMBER: _ClassVar[int]
    _id: str
    email: str
    name: str
    roles: _containers.RepeatedCompositeFieldContainer[role]
    username: str
    def __init__(self, _id: _Optional[str] = ..., name: _Optional[str] = ..., username: _Optional[str] = ..., email: _Optional[str] = ..., roles: _Optional[_Iterable[_Union[role, _Mapping]]] = ...) -> None: ...



from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class unwatch(_message.Message):
    __slots__ = ["id"]
    ID_FIELD_NUMBER: _ClassVar[int]
    id: str
    def __init__(self, id: _Optional[str] = ...) -> None: ...

class unwatchreply(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class watch(_message.Message):
    __slots__ = ["collectionname", "paths"]
    COLLECTIONNAME_FIELD_NUMBER: _ClassVar[int]
    PATHS_FIELD_NUMBER: _ClassVar[int]
    collectionname: str
    paths: _containers.RepeatedScalarFieldContainer[str]
    def __init__(self, collectionname: _Optional[str] = ..., paths: _Optional[_Iterable[str]] = ...) -> None: ...

class watchevent(_message.Message):
    __slots__ = ["document", "id", "operation"]
    DOCUMENT_FIELD_NUMBER: _ClassVar[int]
    ID_FIELD_NUMBER: _ClassVar[int]
    OPERATION_FIELD_NUMBER: _ClassVar[int]
    document: str
    id: str
    operation: str
    def __init__(self, id: _Optional[str] = ..., operation: _Optional[str] = ..., document: _Optional[str] = ...) -> None: ...

class watchreply(_message.Message):
    __slots__ = ["id"]
    ID_FIELD_NUMBER: _ClassVar[int]
    id: str
    def __init__(self, id: _Optional[str] = ...) -> None: ...



from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class queueevent(_message.Message):
    __slots__ = ["correlationId", "data", "exchangename", "queuename", "replyto", "routingkey"]
    CORRELATIONID_FIELD_NUMBER: _ClassVar[int]
    DATA_FIELD_NUMBER: _ClassVar[int]
    EXCHANGENAME_FIELD_NUMBER: _ClassVar[int]
    QUEUENAME_FIELD_NUMBER: _ClassVar[int]
    REPLYTO_FIELD_NUMBER: _ClassVar[int]
    ROUTINGKEY_FIELD_NUMBER: _ClassVar[int]
    correlationId: str
    data: str
    exchangename: str
    queuename: str
    replyto: str
    routingkey: str
    def __init__(self, queuename: _Optional[str] = ..., correlationId: _Optional[str] = ..., replyto: _Optional[str] = ..., routingkey: _Optional[str] = ..., exchangename: _Optional[str] = ..., data: _Optional[str] = ...) -> None: ...

class queuemessage(_message.Message):
    __slots__ = ["correlationId", "data", "exchangename", "queuename", "replyto", "routingkey", "striptoken"]
    CORRELATIONID_FIELD_NUMBER: _ClassVar[int]
    DATA_FIELD_NUMBER: _ClassVar[int]
    EXCHANGENAME_FIELD_NUMBER: _ClassVar[int]
    QUEUENAME_FIELD_NUMBER: _ClassVar[int]
    REPLYTO_FIELD_NUMBER: _ClassVar[int]
    ROUTINGKEY_FIELD_NUMBER: _ClassVar[int]
    STRIPTOKEN_FIELD_NUMBER: _ClassVar[int]
    correlationId: str
    data: str
    exchangename: str
    queuename: str
    replyto: str
    routingkey: str
    striptoken: bool
    def __init__(self, queuename: _Optional[str] = ..., correlationId: _Optional[str] = ..., replyto: _Optional[str] = ..., routingkey: _Optional[str] = ..., exchangename: _Optional[str] = ..., data: _Optional[str] = ..., striptoken: bool = ...) -> None: ...

class queuemessagereply(_message.Message):
    __slots__ = ["correlationId", "data", "exchangename", "queuename", "replyto", "routingkey"]
    CORRELATIONID_FIELD_NUMBER: _ClassVar[int]
    DATA_FIELD_NUMBER: _ClassVar[int]
    EXCHANGENAME_FIELD_NUMBER: _ClassVar[int]
    QUEUENAME_FIELD_NUMBER: _ClassVar[int]
    REPLYTO_FIELD_NUMBER: _ClassVar[int]
    ROUTINGKEY_FIELD_NUMBER: _ClassVar[int]
    correlationId: str
    data: str
    exchangename: str
    queuename: str
    replyto: str
    routingkey: str
    def __init__(self, queuename: _Optional[str] = ..., correlationId: _Optional[str] = ..., replyto: _Optional[str] = ..., routingkey: _Optional[str] = ..., exchangename: _Optional[str] = ..., data: _Optional[str] = ...) -> None: ...

class registerexchange(_message.Message):
    __slots__ = ["addqueue", "algorithm", "exchangename", "routingkey"]
    ADDQUEUE_FIELD_NUMBER: _ClassVar[int]
    ALGORITHM_FIELD_NUMBER: _ClassVar[int]
    EXCHANGENAME_FIELD_NUMBER: _ClassVar[int]
    ROUTINGKEY_FIELD_NUMBER: _ClassVar[int]
    addqueue: bool
    algorithm: str
    exchangename: str
    routingkey: str
    def __init__(self, exchangename: _Optional[str] = ..., algorithm: _Optional[str] = ..., routingkey: _Optional[str] = ..., addqueue: bool = ...) -> None: ...

class registerexchangereply(_message.Message):
    __slots__ = ["queuename"]
    QUEUENAME_FIELD_NUMBER: _ClassVar[int]
    queuename: str
    def __init__(self, queuename: _Optional[str] = ...) -> None: ...

class registerqueue(_message.Message):
    __slots__ = ["queuename"]
    QUEUENAME_FIELD_NUMBER: _ClassVar[int]
    queuename: str
    def __init__(self, queuename: _Optional[str] = ...) -> None: ...

class registerqueuereply(_message.Message):
    __slots__ = ["queuename"]
    QUEUENAME_FIELD_NUMBER: _ClassVar[int]
    queuename: str
    def __init__(self, queuename: _Optional[str] = ...) -> None: ...

class unregisterqueue(_message.Message):
    __slots__ = ["queuename"]
    QUEUENAME_FIELD_NUMBER: _ClassVar[int]
    queuename: str
    def __init__(self, queuename: _Optional[str] = ...) -> None: ...

class unregisterqueuereply(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...



from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class aggregate(_message.Message):
    __slots__ = ["aggregates", "collectionname", "hint", "queryas"]
    AGGREGATES_FIELD_NUMBER: _ClassVar[int]
    COLLECTIONNAME_FIELD_NUMBER: _ClassVar[int]
    HINT_FIELD_NUMBER: _ClassVar[int]
    QUERYAS_FIELD_NUMBER: _ClassVar[int]
    aggregates: str
    collectionname: str
    hint: str
    queryas: str
    def __init__(self, collectionname: _Optional[str] = ..., aggregates: _Optional[str] = ..., queryas: _Optional[str] = ..., hint: _Optional[str] = ...) -> None: ...

class aggregatereply(_message.Message):
    __slots__ = ["results"]
    RESULTS_FIELD_NUMBER: _ClassVar[int]
    results: str
    def __init__(self, results: _Optional[str] = ...) -> None: ...

class count(_message.Message):
    __slots__ = ["collectionname", "query", "queryas"]
    COLLECTIONNAME_FIELD_NUMBER: _ClassVar[int]
    QUERYAS_FIELD_NUMBER: _ClassVar[int]
    QUERY_FIELD_NUMBER: _ClassVar[int]
    collectionname: str
    query: str
    queryas: str
    def __init__(self, collectionname: _Optional[str] = ..., query: _Optional[str] = ..., queryas: _Optional[str] = ...) -> None: ...

class countreply(_message.Message):
    __slots__ = ["result"]
    RESULT_FIELD_NUMBER: _ClassVar[int]
    result: int
    def __init__(self, result: _Optional[int] = ...) -> None: ...

class deletemany(_message.Message):
    __slots__ = ["collectionname", "ids", "query", "recursive"]
    COLLECTIONNAME_FIELD_NUMBER: _ClassVar[int]
    IDS_FIELD_NUMBER: _ClassVar[int]
    QUERY_FIELD_NUMBER: _ClassVar[int]
    RECURSIVE_FIELD_NUMBER: _ClassVar[int]
    collectionname: str
    ids: _containers.RepeatedScalarFieldContainer[str]
    query: str
    recursive: bool
    def __init__(self, collectionname: _Optional[str] = ..., query: _Optional[str] = ..., recursive: bool = ..., ids: _Optional[_Iterable[str]] = ...) -> None: ...

class deletemanyreply(_message.Message):
    __slots__ = ["affectedrows"]
    AFFECTEDROWS_FIELD_NUMBER: _ClassVar[int]
    affectedrows: int
    def __init__(self, affectedrows: _Optional[int] = ...) -> None: ...

class deleteone(_message.Message):
    __slots__ = ["collectionname", "id", "recursive"]
    COLLECTIONNAME_FIELD_NUMBER: _ClassVar[int]
    ID_FIELD_NUMBER: _ClassVar[int]
    RECURSIVE_FIELD_NUMBER: _ClassVar[int]
    collectionname: str
    id: str
    recursive: bool
    def __init__(self, collectionname: _Optional[str] = ..., id: _Optional[str] = ..., recursive: bool = ...) -> None: ...

class deleteonereply(_message.Message):
    __slots__ = ["affectedrows"]
    AFFECTEDROWS_FIELD_NUMBER: _ClassVar[int]
    affectedrows: int
    def __init__(self, affectedrows: _Optional[int] = ...) -> None: ...

class dropcollection(_message.Message):
    __slots__ = ["collectionname"]
    COLLECTIONNAME_FIELD_NUMBER: _ClassVar[int]
    collectionname: str
    def __init__(self, collectionname: _Optional[str] = ...) -> None: ...

class dropcollectionreply(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class getdocumentversion(_message.Message):
    __slots__ = ["collectionname", "decrypt", "id", "version"]
    COLLECTIONNAME_FIELD_NUMBER: _ClassVar[int]
    DECRYPT_FIELD_NUMBER: _ClassVar[int]
    ID_FIELD_NUMBER: _ClassVar[int]
    VERSION_FIELD_NUMBER: _ClassVar[int]
    collectionname: str
    decrypt: bool
    id: str
    version: int
    def __init__(self, collectionname: _Optional[str] = ..., id: _Optional[str] = ..., version: _Optional[int] = ..., decrypt: bool = ...) -> None: ...

class getdocumentversionreply(_message.Message):
    __slots__ = ["result"]
    RESULT_FIELD_NUMBER: _ClassVar[int]
    result: str
    def __init__(self, result: _Optional[str] = ...) -> None: ...

class insertmany(_message.Message):
    __slots__ = ["collectionname", "items", "j", "skipresults", "w"]
    COLLECTIONNAME_FIELD_NUMBER: _ClassVar[int]
    ITEMS_FIELD_NUMBER: _ClassVar[int]
    J_FIELD_NUMBER: _ClassVar[int]
    SKIPRESULTS_FIELD_NUMBER: _ClassVar[int]
    W_FIELD_NUMBER: _ClassVar[int]
    collectionname: str
    items: str
    j: bool
    skipresults: bool
    w: int
    def __init__(self, collectionname: _Optional[str] = ..., items: _Optional[str] = ..., w: _Optional[int] = ..., j: bool = ..., skipresults: bool = ...) -> None: ...

class insertmanyreply(_message.Message):
    __slots__ = ["results"]
    RESULTS_FIELD_NUMBER: _ClassVar[int]
    results: str
    def __init__(self, results: _Optional[str] = ...) -> None: ...

class insertone(_message.Message):
    __slots__ = ["collectionname", "item", "j", "w"]
    COLLECTIONNAME_FIELD_NUMBER: _ClassVar[int]
    ITEM_FIELD_NUMBER: _ClassVar[int]
    J_FIELD_NUMBER: _ClassVar[int]
    W_FIELD_NUMBER: _ClassVar[int]
    collectionname: str
    item: str
    j: bool
    w: int
    def __init__(self, collectionname: _Optional[str] = ..., item: _Optional[str] = ..., w: _Optional[int] = ..., j: bool = ...) -> None: ...

class insertonereply(_message.Message):
    __slots__ = ["result"]
    RESULT_FIELD_NUMBER: _ClassVar[int]
    result: str
    def __init__(self, result: _Optional[str] = ...) -> None: ...

class insertorupdatemany(_message.Message):
    __slots__ = ["collectionname", "items", "j", "skipresults", "uniqeness", "w"]
    COLLECTIONNAME_FIELD_NUMBER: _ClassVar[int]
    ITEMS_FIELD_NUMBER: _ClassVar[int]
    J_FIELD_NUMBER: _ClassVar[int]
    SKIPRESULTS_FIELD_NUMBER: _ClassVar[int]
    UNIQENESS_FIELD_NUMBER: _ClassVar[int]
    W_FIELD_NUMBER: _ClassVar[int]
    collectionname: str
    items: str
    j: bool
    skipresults: bool
    uniqeness: str
    w: int
    def __init__(self, collectionname: _Optional[str] = ..., uniqeness: _Optional[str] = ..., items: _Optional[str] = ..., w: _Optional[int] = ..., j: bool = ..., skipresults: bool = ...) -> None: ...

class insertorupdatemanyreply(_message.Message):
    __slots__ = ["results"]
    RESULTS_FIELD_NUMBER: _ClassVar[int]
    results: str
    def __init__(self, results: _Optional[str] = ...) -> None: ...

class insertorupdateone(_message.Message):
    __slots__ = ["collectionname", "item", "j", "uniqeness", "w"]
    COLLECTIONNAME_FIELD_NUMBER: _ClassVar[int]
    ITEM_FIELD_NUMBER: _ClassVar[int]
    J_FIELD_NUMBER: _ClassVar[int]
    UNIQENESS_FIELD_NUMBER: _ClassVar[int]
    W_FIELD_NUMBER: _ClassVar[int]
    collectionname: str
    item: str
    j: bool
    uniqeness: str
    w: int
    def __init__(self, collectionname: _Optional[str] = ..., uniqeness: _Optional[str] = ..., item: _Optional[str] = ..., w: _Optional[int] = ..., j: bool = ...) -> None: ...

class insertorupdateonereply(_message.Message):
    __slots__ = ["result"]
    RESULT_FIELD_NUMBER: _ClassVar[int]
    result: str
    def __init__(self, result: _Optional[str] = ...) -> None: ...

class listcollections(_message.Message):
    __slots__ = ["includehist"]
    INCLUDEHIST_FIELD_NUMBER: _ClassVar[int]
    includehist: bool
    def __init__(self, includehist: bool = ...) -> None: ...

class listcollectionsreply(_message.Message):
    __slots__ = ["results"]
    RESULTS_FIELD_NUMBER: _ClassVar[int]
    results: str
    def __init__(self, results: _Optional[str] = ...) -> None: ...

class query(_message.Message):
    __slots__ = ["collectionname", "orderby", "projection", "query", "queryas", "skip", "top"]
    COLLECTIONNAME_FIELD_NUMBER: _ClassVar[int]
    ORDERBY_FIELD_NUMBER: _ClassVar[int]
    PROJECTION_FIELD_NUMBER: _ClassVar[int]
    QUERYAS_FIELD_NUMBER: _ClassVar[int]
    QUERY_FIELD_NUMBER: _ClassVar[int]
    SKIP_FIELD_NUMBER: _ClassVar[int]
    TOP_FIELD_NUMBER: _ClassVar[int]
    collectionname: str
    orderby: str
    projection: str
    query: str
    queryas: str
    skip: int
    top: int
    def __init__(self, query: _Optional[str] = ..., collectionname: _Optional[str] = ..., projection: _Optional[str] = ..., top: _Optional[int] = ..., skip: _Optional[int] = ..., orderby: _Optional[str] = ..., queryas: _Optional[str] = ...) -> None: ...

class queryreply(_message.Message):
    __slots__ = ["results"]
    RESULTS_FIELD_NUMBER: _ClassVar[int]
    results: str
    def __init__(self, results: _Optional[str] = ...) -> None: ...

class updatedocument(_message.Message):
    __slots__ = ["collectionname", "document", "j", "query", "w"]
    COLLECTIONNAME_FIELD_NUMBER: _ClassVar[int]
    DOCUMENT_FIELD_NUMBER: _ClassVar[int]
    J_FIELD_NUMBER: _ClassVar[int]
    QUERY_FIELD_NUMBER: _ClassVar[int]
    W_FIELD_NUMBER: _ClassVar[int]
    collectionname: str
    document: str
    j: bool
    query: str
    w: int
    def __init__(self, collectionname: _Optional[str] = ..., query: _Optional[str] = ..., document: _Optional[str] = ..., w: _Optional[int] = ..., j: bool = ...) -> None: ...

class updatedocumentreply(_message.Message):
    __slots__ = ["opresult"]
    OPRESULT_FIELD_NUMBER: _ClassVar[int]
    opresult: updateresult
    def __init__(self, opresult: _Optional[_Union[updateresult, _Mapping]] = ...) -> None: ...

class updateone(_message.Message):
    __slots__ = ["collectionname", "item", "j", "w"]
    COLLECTIONNAME_FIELD_NUMBER: _ClassVar[int]
    ITEM_FIELD_NUMBER: _ClassVar[int]
    J_FIELD_NUMBER: _ClassVar[int]
    W_FIELD_NUMBER: _ClassVar[int]
    collectionname: str
    item: str
    j: bool
    w: int
    def __init__(self, collectionname: _Optional[str] = ..., item: _Optional[str] = ..., w: _Optional[int] = ..., j: bool = ...) -> None: ...

class updateonereply(_message.Message):
    __slots__ = ["result"]
    RESULT_FIELD_NUMBER: _ClassVar[int]
    result: str
    def __init__(self, result: _Optional[str] = ...) -> None: ...

class updateresult(_message.Message):
    __slots__ = ["acknowledged", "matchedCount", "modifiedCount", "upsertedCount", "upsertedId"]
    ACKNOWLEDGED_FIELD_NUMBER: _ClassVar[int]
    MATCHEDCOUNT_FIELD_NUMBER: _ClassVar[int]
    MODIFIEDCOUNT_FIELD_NUMBER: _ClassVar[int]
    UPSERTEDCOUNT_FIELD_NUMBER: _ClassVar[int]
    UPSERTEDID_FIELD_NUMBER: _ClassVar[int]
    acknowledged: bool
    matchedCount: int
    modifiedCount: int
    upsertedCount: int
    upsertedId: str
    def __init__(self, acknowledged: bool = ..., matchedCount: _Optional[int] = ..., modifiedCount: _Optional[int] = ..., upsertedCount: _Optional[int] = ..., upsertedId: _Optional[str] = ...) -> None: ...



from google.protobuf import timestamp_pb2 as _timestamp_pb2
import ace_pb2 as _ace_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class addworkitemqueue(_message.Message):
    __slots__ = ["_acl", "amqpqueue", "failed_wiq", "failed_wiqid", "initialdelay", "maxretries", "name", "projectid", "retrydelay", "robotqueue", "skiprole", "success_wiq", "success_wiqid"]
    AMQPQUEUE_FIELD_NUMBER: _ClassVar[int]
    FAILED_WIQID_FIELD_NUMBER: _ClassVar[int]
    FAILED_WIQ_FIELD_NUMBER: _ClassVar[int]
    INITIALDELAY_FIELD_NUMBER: _ClassVar[int]
    MAXRETRIES_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    PROJECTID_FIELD_NUMBER: _ClassVar[int]
    RETRYDELAY_FIELD_NUMBER: _ClassVar[int]
    ROBOTQUEUE_FIELD_NUMBER: _ClassVar[int]
    SKIPROLE_FIELD_NUMBER: _ClassVar[int]
    SUCCESS_WIQID_FIELD_NUMBER: _ClassVar[int]
    SUCCESS_WIQ_FIELD_NUMBER: _ClassVar[int]
    _ACL_FIELD_NUMBER: _ClassVar[int]
    _acl: _containers.RepeatedCompositeFieldContainer[_ace_pb2.ace]
    amqpqueue: str
    failed_wiq: str
    failed_wiqid: str
    initialdelay: int
    maxretries: int
    name: str
    projectid: str
    retrydelay: int
    robotqueue: str
    skiprole: bool
    success_wiq: str
    success_wiqid: str
    def __init__(self, name: _Optional[str] = ..., robotqueue: _Optional[str] = ..., amqpqueue: _Optional[str] = ..., projectid: _Optional[str] = ..., skiprole: bool = ..., maxretries: _Optional[int] = ..., initialdelay: _Optional[int] = ..., retrydelay: _Optional[int] = ..., success_wiqid: _Optional[str] = ..., failed_wiqid: _Optional[str] = ..., success_wiq: _Optional[str] = ..., failed_wiq: _Optional[str] = ..., _acl: _Optional[_Iterable[_Union[_ace_pb2.ace, _Mapping]]] = ...) -> None: ...

class addworkitemqueuereply(_message.Message):
    __slots__ = ["workitemqueue"]
    WORKITEMQUEUE_FIELD_NUMBER: _ClassVar[int]
    workitemqueue: workitemqueue
    def __init__(self, workitemqueue: _Optional[_Union[workitemqueue, _Mapping]] = ...) -> None: ...

class deleteworkitem(_message.Message):
    __slots__ = ["_id"]
    _ID_FIELD_NUMBER: _ClassVar[int]
    _id: str
    def __init__(self, _id: _Optional[str] = ...) -> None: ...

class deleteworkitemreply(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class popworkitem(_message.Message):
    __slots__ = ["compressed", "includefiles", "wiq", "wiqid"]
    COMPRESSED_FIELD_NUMBER: _ClassVar[int]
    INCLUDEFILES_FIELD_NUMBER: _ClassVar[int]
    WIQID_FIELD_NUMBER: _ClassVar[int]
    WIQ_FIELD_NUMBER: _ClassVar[int]
    compressed: bool
    includefiles: bool
    wiq: str
    wiqid: str
    def __init__(self, wiq: _Optional[str] = ..., wiqid: _Optional[str] = ..., includefiles: bool = ..., compressed: bool = ...) -> None: ...

class popworkitemreply(_message.Message):
    __slots__ = ["workitem"]
    WORKITEM_FIELD_NUMBER: _ClassVar[int]
    workitem: workitem
    def __init__(self, workitem: _Optional[_Union[workitem, _Mapping]] = ...) -> None: ...

class pushworkitem(_message.Message):
    __slots__ = ["failed_wiq", "failed_wiqid", "files", "name", "nextrun", "payload", "priority", "success_wiq", "success_wiqid", "wiq", "wiqid"]
    FAILED_WIQID_FIELD_NUMBER: _ClassVar[int]
    FAILED_WIQ_FIELD_NUMBER: _ClassVar[int]
    FILES_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    NEXTRUN_FIELD_NUMBER: _ClassVar[int]
    PAYLOAD_FIELD_NUMBER: _ClassVar[int]
    PRIORITY_FIELD_NUMBER: _ClassVar[int]
    SUCCESS_WIQID_FIELD_NUMBER: _ClassVar[int]
    SUCCESS_WIQ_FIELD_NUMBER: _ClassVar[int]
    WIQID_FIELD_NUMBER: _ClassVar[int]
    WIQ_FIELD_NUMBER: _ClassVar[int]
    failed_wiq: str
    failed_wiqid: str
    files: _containers.RepeatedCompositeFieldContainer[workitemfile]
    name: str
    nextrun: _timestamp_pb2.Timestamp
    payload: str
    priority: int
    success_wiq: str
    success_wiqid: str
    wiq: str
    wiqid: str
    def __init__(self, wiq: _Optional[str] = ..., wiqid: _Optional[str] = ..., name: _Optional[str] = ..., payload: _Optional[str] = ..., nextrun: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., success_wiqid: _Optional[str] = ..., failed_wiqid: _Optional[str] = ..., success_wiq: _Optional[str] = ..., failed_wiq: _Optional[str] = ..., priority: _Optional[int] = ..., files: _Optional[_Iterable[_Union[workitemfile, _Mapping]]] = ...) -> None: ...

class pushworkitemreply(_message.Message):
    __slots__ = ["workitem"]
    WORKITEM_FIELD_NUMBER: _ClassVar[int]
    workitem: workitem
    def __init__(self, workitem: _Optional[_Union[workitem, _Mapping]] = ...) -> None: ...

class pushworkitems(_message.Message):
    __slots__ = ["failed_wiq", "failed_wiqid", "items", "nextrun", "priority", "success_wiq", "success_wiqid", "wiq", "wiqid"]
    FAILED_WIQID_FIELD_NUMBER: _ClassVar[int]
    FAILED_WIQ_FIELD_NUMBER: _ClassVar[int]
    ITEMS_FIELD_NUMBER: _ClassVar[int]
    NEXTRUN_FIELD_NUMBER: _ClassVar[int]
    PRIORITY_FIELD_NUMBER: _ClassVar[int]
    SUCCESS_WIQID_FIELD_NUMBER: _ClassVar[int]
    SUCCESS_WIQ_FIELD_NUMBER: _ClassVar[int]
    WIQID_FIELD_NUMBER: _ClassVar[int]
    WIQ_FIELD_NUMBER: _ClassVar[int]
    failed_wiq: str
    failed_wiqid: str
    items: _containers.RepeatedCompositeFieldContainer[workitem]
    nextrun: _timestamp_pb2.Timestamp
    priority: int
    success_wiq: str
    success_wiqid: str
    wiq: str
    wiqid: str
    def __init__(self, wiq: _Optional[str] = ..., wiqid: _Optional[str] = ..., nextrun: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., success_wiqid: _Optional[str] = ..., failed_wiqid: _Optional[str] = ..., success_wiq: _Optional[str] = ..., failed_wiq: _Optional[str] = ..., priority: _Optional[int] = ..., items: _Optional[_Iterable[_Union[workitem, _Mapping]]] = ...) -> None: ...

class pushworkitemsreply(_message.Message):
    __slots__ = ["workitems"]
    WORKITEMS_FIELD_NUMBER: _ClassVar[int]
    workitems: _containers.RepeatedCompositeFieldContainer[workitem]
    def __init__(self, workitems: _Optional[_Iterable[_Union[workitem, _Mapping]]] = ...) -> None: ...

class updateworkitem(_message.Message):
    __slots__ = ["ignoremaxretries", "workitem"]
    IGNOREMAXRETRIES_FIELD_NUMBER: _ClassVar[int]
    WORKITEM_FIELD_NUMBER: _ClassVar[int]
    ignoremaxretries: bool
    workitem: workitem
    def __init__(self, workitem: _Optional[_Union[workitem, _Mapping]] = ..., ignoremaxretries: bool = ...) -> None: ...

class updateworkitemreply(_message.Message):
    __slots__ = ["workitem"]
    WORKITEM_FIELD_NUMBER: _ClassVar[int]
    workitem: workitem
    def __init__(self, workitem: _Optional[_Union[workitem, _Mapping]] = ...) -> None: ...

class workitem(_message.Message):
    __slots__ = ["_id", "errormessage", "errorsource", "errortype", "failed_wiq", "failed_wiqid", "files", "lastrun", "name", "nextrun", "payload", "priority", "retries", "state", "success_wiq", "success_wiqid", "username", "wiq", "wiqid"]
    ERRORMESSAGE_FIELD_NUMBER: _ClassVar[int]
    ERRORSOURCE_FIELD_NUMBER: _ClassVar[int]
    ERRORTYPE_FIELD_NUMBER: _ClassVar[int]
    FAILED_WIQID_FIELD_NUMBER: _ClassVar[int]
    FAILED_WIQ_FIELD_NUMBER: _ClassVar[int]
    FILES_FIELD_NUMBER: _ClassVar[int]
    LASTRUN_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    NEXTRUN_FIELD_NUMBER: _ClassVar[int]
    PAYLOAD_FIELD_NUMBER: _ClassVar[int]
    PRIORITY_FIELD_NUMBER: _ClassVar[int]
    RETRIES_FIELD_NUMBER: _ClassVar[int]
    STATE_FIELD_NUMBER: _ClassVar[int]
    SUCCESS_WIQID_FIELD_NUMBER: _ClassVar[int]
    SUCCESS_WIQ_FIELD_NUMBER: _ClassVar[int]
    USERNAME_FIELD_NUMBER: _ClassVar[int]
    WIQID_FIELD_NUMBER: _ClassVar[int]
    WIQ_FIELD_NUMBER: _ClassVar[int]
    _ID_FIELD_NUMBER: _ClassVar[int]
    _id: str
    errormessage: str
    errorsource: str
    errortype: str
    failed_wiq: str
    failed_wiqid: str
    files: _containers.RepeatedCompositeFieldContainer[workitemfile]
    lastrun: _timestamp_pb2.Timestamp
    name: str
    nextrun: _timestamp_pb2.Timestamp
    payload: str
    priority: int
    retries: int
    state: str
    success_wiq: str
    success_wiqid: str
    username: str
    wiq: str
    wiqid: str
    def __init__(self, _id: _Optional[str] = ..., name: _Optional[str] = ..., payload: _Optional[str] = ..., priority: _Optional[int] = ..., nextrun: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., lastrun: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., files: _Optional[_Iterable[_Union[workitemfile, _Mapping]]] = ..., state: _Optional[str] = ..., wiq: _Optional[str] = ..., wiqid: _Optional[str] = ..., retries: _Optional[int] = ..., username: _Optional[str] = ..., success_wiqid: _Optional[str] = ..., failed_wiqid: _Optional[str] = ..., success_wiq: _Optional[str] = ..., failed_wiq: _Optional[str] = ..., errormessage: _Optional[str] = ..., errorsource: _Optional[str] = ..., errortype: _Optional[str] = ...) -> None: ...

class workitemfile(_message.Message):
    __slots__ = ["_id", "compressed", "file", "filename"]
    COMPRESSED_FIELD_NUMBER: _ClassVar[int]
    FILENAME_FIELD_NUMBER: _ClassVar[int]
    FILE_FIELD_NUMBER: _ClassVar[int]
    _ID_FIELD_NUMBER: _ClassVar[int]
    _id: str
    compressed: bool
    file: bytes
    filename: str
    def __init__(self, filename: _Optional[str] = ..., _id: _Optional[str] = ..., compressed: bool = ..., file: _Optional[bytes] = ...) -> None: ...

class workitemqueue(_message.Message):
    __slots__ = ["_acl", "_created", "_createdby", "_createdbyid", "_id", "_modified", "_modifiedby", "_modifiedbyid", "_version", "amqpqueue", "failed_wiq", "failed_wiqid", "initialdelay", "maxretries", "name", "projectid", "retrydelay", "robotqueue", "success_wiq", "success_wiqid", "usersrole", "workflowid"]
    AMQPQUEUE_FIELD_NUMBER: _ClassVar[int]
    FAILED_WIQID_FIELD_NUMBER: _ClassVar[int]
    FAILED_WIQ_FIELD_NUMBER: _ClassVar[int]
    INITIALDELAY_FIELD_NUMBER: _ClassVar[int]
    MAXRETRIES_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    PROJECTID_FIELD_NUMBER: _ClassVar[int]
    RETRYDELAY_FIELD_NUMBER: _ClassVar[int]
    ROBOTQUEUE_FIELD_NUMBER: _ClassVar[int]
    SUCCESS_WIQID_FIELD_NUMBER: _ClassVar[int]
    SUCCESS_WIQ_FIELD_NUMBER: _ClassVar[int]
    USERSROLE_FIELD_NUMBER: _ClassVar[int]
    WORKFLOWID_FIELD_NUMBER: _ClassVar[int]
    _ACL_FIELD_NUMBER: _ClassVar[int]
    _CREATEDBYID_FIELD_NUMBER: _ClassVar[int]
    _CREATEDBY_FIELD_NUMBER: _ClassVar[int]
    _CREATED_FIELD_NUMBER: _ClassVar[int]
    _ID_FIELD_NUMBER: _ClassVar[int]
    _MODIFIEDBYID_FIELD_NUMBER: _ClassVar[int]
    _MODIFIEDBY_FIELD_NUMBER: _ClassVar[int]
    _MODIFIED_FIELD_NUMBER: _ClassVar[int]
    _VERSION_FIELD_NUMBER: _ClassVar[int]
    _acl: _containers.RepeatedCompositeFieldContainer[_ace_pb2.ace]
    _created: _timestamp_pb2.Timestamp
    _createdby: str
    _createdbyid: str
    _id: str
    _modified: _timestamp_pb2.Timestamp
    _modifiedby: str
    _modifiedbyid: str
    _version: int
    amqpqueue: str
    failed_wiq: str
    failed_wiqid: str
    initialdelay: int
    maxretries: int
    name: str
    projectid: str
    retrydelay: int
    robotqueue: str
    success_wiq: str
    success_wiqid: str
    usersrole: str
    workflowid: str
    def __init__(self, workflowid: _Optional[str] = ..., robotqueue: _Optional[str] = ..., amqpqueue: _Optional[str] = ..., projectid: _Optional[str] = ..., usersrole: _Optional[str] = ..., maxretries: _Optional[int] = ..., retrydelay: _Optional[int] = ..., initialdelay: _Optional[int] = ..., success_wiqid: _Optional[str] = ..., failed_wiqid: _Optional[str] = ..., success_wiq: _Optional[str] = ..., failed_wiq: _Optional[str] = ..., _id: _Optional[str] = ..., _acl: _Optional[_Iterable[_Union[_ace_pb2.ace, _Mapping]]] = ..., name: _Optional[str] = ..., _createdbyid: _Optional[str] = ..., _createdby: _Optional[str] = ..., _created: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., _modifiedbyid: _Optional[str] = ..., _modifiedby: _Optional[str] = ..., _modified: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., _version: _Optional[int] = ...) -> None: ...
